chiark / gitweb /
util: truncmsg: New way of manipulating buffers
[secnet.git] / util.h
diff --git a/util.h b/util.h
index 0a965564ec679a71ea2b5cebc5ff1fc82a37b285..d783cd076b10c7a70ecd7b215ba2947d61913d08 100644 (file)
--- a/util.h
+++ b/util.h
@@ -49,6 +49,16 @@ extern void *buf_prepend(struct buffer_if *buf, int32_t amount);
 extern void *buf_unappend(struct buffer_if *buf, int32_t amount);
 extern void *buf_unprepend(struct buffer_if *buf, int32_t amount);
 
+/* These construct a message in a buffer, truncating if necessary.
+ * _string is only safe for trusted input and *not* UTF-8 (sorry).
+ * _packet_string is safe for any input, including untrusted.
+ * _terminate arranges for the buffer to be null-terminated (and
+ * maybe for a trailing `...' to indicate truncation), and returns
+ * a pointer to the null-terminated string. */
+void truncmsg_add_string(struct buffer_if *buf, cstring_t s);
+void truncmsg_add_packet_string(struct buffer_if*, int32_t, const uint8_t*);
+const char *truncmsg_terminate(const struct buffer_if *buf);
+
 /*
  * void BUF_ADD_BYTES(append,    struct buffer_if*, const void*, int32_t size);
  * void BUF_ADD_BYTES(prepend,   struct buffer_if*, const void*, int32_t size);
@@ -89,9 +99,11 @@ extern void buf_append_string(struct buffer_if *buf, cstring_t s);
   /* Append a two-byte length and the string to the buffer. Length is in
    * network byte order. */
 
-extern string_t hex_encode(const uint8_t *bin, int binsize);
-  /* Convert a byte array to hex, returning the result in a freshly allocated
-   * string. */
+static inline int hex_encode_size(int binsize) { return binsize*2 + 1; }
+extern void hex_encode(const uint8_t *bin, int binsize, char *buf);
+  /* Convert a byte array to hex into a supplied buffer. */
+extern string_t hex_encode_alloc(const uint8_t *bin, int binsize);
+  /* Returns the result in a freshly allocated string. */
 
 extern bool_t hex_decode(uint8_t *buffer, int32_t buflen, int32_t *outlen,
                         cstring_t hb, bool_t allow_odd_nibble);
@@ -122,6 +134,9 @@ extern void send_nak(const struct comm_addr *dest, uint32_t our_index,
 
 extern int consttime_memeq(const void *s1, const void *s2, size_t n);
 
+void hash_hash(const struct hash_if *hashi, const void *msg, int32_t len,
+              uint8_t *digest /* hi->hlen bytes */);
+
 const char *iaddr_to_string(const union iaddr *ia);
 int iaddr_socklen(const union iaddr *ia);